package com.streambase.contrib.earthquake;

import java.net.URL;
import java.util.ArrayList;
import java.util.List;
import net.htmlparser.jericho.Source;
import net.htmlparser.jericho.StartTag;
import com.streambase.contrib.earthquake.EarthquakeSchema;
import com.streambase.sb.*;
import com.streambase.sb.adapter.*;
import com.streambase.sb.operator.*;
import com.streambase.contrib.earthquake.IRIS;

public class EarthquakeMonitor extends InputAdapter implements Parameterizable,
		Runnable {

	public static final long serialVersionUID = 1299958019472L;
	public static final String IRIS_ADDRESS = "http://www.iris.edu/seismon/last30.html";
	// Properties
	private int Period;
	private String displayName = "EarthquakeMonitor";	
	private boolean firstRun;
	private boolean initialization;
	private ArrayList<String> mostRecent = null; 
	private ArrayList<String> lastMostRecent = null; 

	public EarthquakeMonitor() {
		super();		
		setPortHints(0, 1);
		setDisplayName(displayName);
		setShortDisplayName(this.getClass().getSimpleName());
		setPeriod(30);
		firstRun = false;
		initialization = false;
	}

	public void typecheck() throws TypecheckException {
		setOutputSchema(0, EarthquakeSchema.SCHEMA);
	}

	/**
	 * Initialize the adapter. If typecheck succeeds, the init method is called before
	 * the StreamBase application is started. Note that your adapter is not required to
	 * define the init method, unless you need to register a runnable or perform
	 * initialization of a resource such as, for example, a JDBC pool.
	 */
	public void init() throws StreamBaseException {
		super.init();
		// Register the object so it will be run as a thread managed by StreamBase.
		registerRunnable(this, true);
	}

	/**
	 * Shutdown adapter by cleaning up any resources used (e.g. close an output file
	 * if it has been opened). When the application is shutting down, the adapter's shutdown.
	 * method will be called first. Once this has returned, all threads should exit and the
	 * adapter is considered shutdown.
	 */
	public void shutdown() {

	}

	/**
	 * Main thread of the adapter. At this point, the application begins to run.
	 * StreamBase will start threads for any managed runnables registered by
	 * earlier calls to registerRunnable. Input adapters can call sendOutput(port, tuple) 
	 * at any time to output a tuple to the specified port.
	 */
	public void run() {
		// fill the tuple and output the tuple
		fillAndOutputTuple();
	}

	protected void fillAndOutputTuple() {
		Schema schema = getOutputSchema(0);
        Tuple output = schema.createTuple();
        Source source;
		try {
			while (shouldRun()) {
				source = new Source(new URL(IRIS_ADDRESS));
				List<StartTag> tags = source.getAllStartTags("tr bgcolor");
				if (!initialization){														
					for (StartTag tag : tags){
						output.clear();
						ArrayList<String> entry = IRIS.parseTag(tag);						
						output.setString("Timestamp", entry.get(0).trim());
						output.setDouble("Latitude", Double.valueOf(entry.get(1).trim()).doubleValue());
						output.setDouble("Longitude", Double.valueOf(entry.get(2).trim()).doubleValue());
						output.setDouble("Magnitude", Double.valueOf(entry.get(3)).doubleValue());
						output.setDouble("Depth", Double.valueOf(entry.get(4)).doubleValue());
						output.setString("Region", entry.get(5));
						sendOutput(0, output);
						if (!firstRun){
							mostRecent = entry;
							firstRun = true;
						}
					}
					initialization = true;
					firstRun = false;					
				} else {						
					lastMostRecent = mostRecent;
					for (StartTag tag : tags){						
						ArrayList<String> entry = IRIS.parseTag(tag);
						if (!lastMostRecent.equals(entry)){
							output.clear();
							output.setString("Timestamp", entry.get(0).trim());
							output.setDouble("Latitude", Double.valueOf(entry.get(1).trim()).doubleValue());
							output.setDouble("Longitude", Double.valueOf(entry.get(2).trim()).doubleValue());
							output.setDouble("Magnitude", Double.valueOf(entry.get(3)).doubleValue());
							output.setDouble("Depth", Double.valueOf(entry.get(4)).doubleValue());
							output.setString("Region", entry.get(5));
							sendOutput(0, output);
							if (!firstRun){
								mostRecent = entry;
								firstRun = true;
							}								
						} else {
							firstRun = false;
							break; 
						}
					}				
				}
				
			}
			Thread.sleep(getPeriod()*1000);
		} catch (Exception e){
			System.out.println("Error Occurred: + " + e);
		}
	}
	
	/***************************************************************************************
	 * The following methods are specifically for this                *
	 * StreamBase Studio uses them to determine the name and type of each property         *
	 * and obviously, to set and get the property values.                                  *
	 ***************************************************************************************/

	/***************************************************************************************
	 * The getter and setter methods provided by the Parameterizable object.               *
	 * StreamBase Studio uses them to determine the name and type of each property         *
	 * and obviously, to set and get the property values.                                  *
	 ***************************************************************************************/

	public void setPeriod(int Period) {
		this.Period = Period;
	}

	public int getPeriod() {
		return this.Period;
	}
	
}
