package com.streambase.contrib.earthquake;

import net.htmlparser.jericho.*;
import java.util.*;

public class IRIS {	
	public static final String IRIS_ADDRESS = "http://www.iris.edu/seismon/last30.html";		
	
	/**
	 * Outputs all the earthquakes worldwide in the last 30 days
	 */
	public static ArrayList<String> parseTag(Tag tag){		
			ArrayList<String> fields = new ArrayList<String>();
			Element elements = tag.getElement();
			for (Element element : elements.getAllElements("th")){
				List<Element> font = element.getAllElements("font");
				List<Element> ahref = element.getAllElements("a href");
				if (font.size() > 0)
					fields.add(font.get(0).getContent().toString());					
				else if (ahref.size() > 0)
					fields.add(ahref.get(0).getContent().toString());
				else {
					fields.add(element.getContent().toString());
				}				
			}	
			return fields;
	}
	
	/**
	 * Get the distance between two points on the earth
	 * @param lat1 is the first angular distance, in degrees, minutes, and seconds of a point north or south of the Equator 
	 * @param lon1 is the first angular distance, in degrees, minutes, and seconds, of a point east or west of the Prime (Greenwich) Meridian 
	 * @param lat2 is the second angular distance, in degrees, minutes, and seconds of a point north or south of the Equator
	 * @param lon2 is the second angular distance, in degrees, minutes, and seconds, of a point east or west of the Prime (Greenwich) Meridian 
	 * @return
	 */
	public static double getDistance(double lat1, double lon1, double lat2, double lon2){
		double R = 6371.0; // Radius of the earth in km
		double dLat = Math.toRadians(lat2-lat1); 
		double dLon = Math.toRadians(lon2-lon1); 
		double a = Math.sin(dLat/2) * Math.sin(dLat/2)+ Math.cos(Math.toRadians(lat1)) * Math.cos(Math.toRadians(lat2)) * Math.sin(dLon/2) * Math.sin(dLon/2); 
		double c = 2 * Math.atan2(Math.sqrt(a), Math.sqrt(1-a)); 
		return R * c; // Distance in km	
	}		
}