package com.streambase.contrib.map;

import java.awt.Color;
import java.util.ArrayList;

import com.bbn.openmap.Layer;
import com.bbn.openmap.omGraphics.*;
import com.bbn.openmap.event.ProjectionEvent;

public class PointLayer extends Layer {

	private static final long serialVersionUID = -7958850319900786420L;
	
	/** A list that holds all the longitude and latitude points */
	private ArrayList<Float> lat = null;
	private ArrayList<Float> lon = null;	

	/** A list of graphics to be painted on the map. */
    private OMGraphicList omgraphics;
    
    /**
     * Construct a default point layer. Initializes omgraphics to a
     * new OMGraphicList, and invokes createGraphics to create the
     * list of the most recent earthquakes. Note that in this 
     * constructor, not set of earthquakes is passed into the class.
     */
    public PointLayer() {   	
        omgraphics = new OMGraphicList();
        this.lat = new ArrayList<Float>();
        this.lon = new ArrayList<Float>();                
    }

    /**
     * Creates an OMLine from the given parameters.
     * @param lat The points latitude
     * @param lng The points longitude
     * @param color The line's color
     * @return An OMPoint with the given properties
     */
    public OMPoint createPoint(float lat, float lon, Color color) {
    	OMPoint point = new OMPoint(lat, lon,4);
    	point.setLinePaint(color);
    	point.setLineType(0);
    	return point;
    }

    /**
     * Clears and then fills the given OMGraphicList. Instantiates
     * all the points on the map where earthquakes took place.
     * @param graphics The OMGraphicList to clear and populate
     * @param lat The latitude coordinate of the earthquakes
     * @param lon The longitude coordinate of the earthquakes
     * @return the graphics list, after being cleared and filled
     */
	public OMGraphicList createGraphics(OMGraphicList graphics) {
		graphics.clear();
		if (this.lat != null && this.lon != null && !this.lat.isEmpty() && this.lat.size () == this.lon.size()){			
			for(int i = 0; i < this.lat.size(); i++){
				//graphics.addOMGraphic(createPoint(this.lat.get(i), this.lon.get(i), Color.red));				
				graphics.add(createPoint(this.lat.get(i), this.lon.get(i), Color.red));
			}			  
		}
	    return graphics;		        
	}
	
	/**
	 * This function clears all the earthquakes stored
	 */
	public void clearEarthquakes(){		
		this.lat.clear();
		this.lon.clear();
		this.omgraphics.clear();
	}
	
	/**
	 * Adds a new coordinate to the earthquake list 
     * @param lat The points latitude
     * @param lng The points longitude
	 */
	public void addEarthquake(float latitude, float longitude){
		this.lat.add(latitude);
		this.lon.add(longitude);		
	}
	
	/**
	 * Create the graphics that will be painted on the screen 
	 */
	public void createGraphics(){
		createGraphics(omgraphics);
	}

	
    //----------------------------------------------------------------------
    // Layer overrides
    //----------------------------------------------------------------------

    /**
     * Renders the graphics list. It is important to make this routine
     * as fast as possible since it is called frequently by Swing, and
     * the User Interface blocks while painting is done.
     */
    public void paint(java.awt.Graphics g) {
        omgraphics.render(g);
    }
  
    //----------------------------------------------------------------------
    // ProjectionListener interface implementation
    //----------------------------------------------------------------------

    /**
     * Handler for ProjectionEvent. This function is
     * invoked when the MapBean projection changes. The
     * graphics are reprojected and then the Layer is repainted.
     * @param e the projection event
     */
    public void projectionChanged(ProjectionEvent e) {
        omgraphics.project(e.getProjection(), true);
        repaint();
    } 

}